@@ -10,22 +10,21 @@
 #include "glossary.h"
 #include "docentry.h"
 
-#include <grantlee/context.h>
-#include <grantlee/engine.h>
-#include <grantlee/template.h>
-#include <grantlee/templateloader.h>
+#include <KTextTemplate/Context>
+#include <KTextTemplate/Engine>
+#include <KTextTemplate/Template>
+#include <KTextTemplate/TemplateLoader>
 
 #include <KLocalizedString>
 
 #include <QStandardPaths>
 
 using namespace KHC;
-
-class PlainOutputStream : public Grantlee::OutputStream
+class PlainOutputStream : public KTextTemplate::OutputStream
 {
   public:
     explicit PlainOutputStream( QTextStream *stream )
-      : Grantlee::OutputStream( stream )
+      : KTextTemplate::OutputStream( stream )
     {
     }
 
@@ -42,12 +41,12 @@ class PlainOutputStream : public Grantlee::OutputStream
 
 struct GrantleeFormatter::Private
 {
-  QString format( Grantlee::Template t, Grantlee::Context *ctx );
+  QString format( KTextTemplate::Template t, KTextTemplate::Context *ctx );
 
-  Grantlee::Engine engine;
+  KTextTemplate::Engine engine;
 };
 
-QString GrantleeFormatter::Private::format( Grantlee::Template t, Grantlee::Context *ctx )
+QString GrantleeFormatter::Private::format( KTextTemplate::Template t, KTextTemplate::Context *ctx )
 {
   QString result;
   QTextStream textStream( &result );
@@ -64,7 +63,7 @@ QString GrantleeFormatter::Private::format( Grantlee::Template t, Grantlee::Cont
 GrantleeFormatter::GrantleeFormatter()
   : d( new Private )
 {
-  QSharedPointer< Grantlee::FileSystemTemplateLoader > loader( new Grantlee::FileSystemTemplateLoader );
+  QSharedPointer< KTextTemplate::FileSystemTemplateLoader > loader( new KTextTemplate::FileSystemTemplateLoader );
   loader->setTemplateDirs( QStandardPaths::locateAll( QStandardPaths::AppDataLocation, QStringLiteral("templates"), QStandardPaths::LocateDirectory ) );
   d->engine.addTemplateLoader( loader );
 }
@@ -76,9 +75,8 @@ GrantleeFormatter::~GrantleeFormatter()
 
 QString GrantleeFormatter::formatOverview( const QString& title, const QString& name, const QString& content )
 {
-  Grantlee::Template t = d->engine.loadByName( QStringLiteral("index.html") );
-
-  Grantlee::Context ctx;
+  KTextTemplate::Template t = d->engine.loadByName( QStringLiteral("index.html") );
+  KTextTemplate::Context ctx;
   ctx.insert( QStringLiteral("title"), title );
   ctx.insert( QStringLiteral("name"), name );
   ctx.insert( QStringLiteral("content"), content );
@@ -88,7 +86,8 @@ QString GrantleeFormatter::formatOverview( const QString& title, const QString&
 
 QString GrantleeFormatter::formatGlossaryEntry( const GlossaryEntry& entry )
 {
-  Grantlee::Template t = d->engine.loadByName( QStringLiteral("glossary.html") );
+  KTextTemplate::Template t = d->engine.loadByName( QStringLiteral("glossary.html") );
+  KTextTemplate::Context ctx;
 
   const GlossaryEntryXRef::List entrySeeAlso = entry.seeAlso();
   QStringList seeAlso;
@@ -98,7 +97,6 @@ QString GrantleeFormatter::formatGlossaryEntry( const GlossaryEntry& entry )
     seeAlso += QStringLiteral( "<a href=\"glossentry:%1\">%2</a>" ).arg( xref.id(), xref.term() );
   }
 
-  Grantlee::Context ctx;
   ctx.insert( QStringLiteral("htmltitle"), i18nc( "%1 is a glossary term", "KDE Glossary: %1", entry.term() ) );
   ctx.insert( QStringLiteral("title"), i18n( "KDE Glossary" ) );
   ctx.insert( QStringLiteral("term"), entry.term() );
@@ -111,7 +109,8 @@ QString GrantleeFormatter::formatGlossaryEntry( const GlossaryEntry& entry )
 
 QString GrantleeFormatter::formatSearchResults( const QString& words, const QList<QPair<DocEntry *, QString> >& results )
 {
-  Grantlee::Template t = d->engine.loadByName( QStringLiteral("search.html") );
+    KTextTemplate::Template t = d->engine.loadByName( QStringLiteral("search.html") );
+    KTextTemplate::Context ctx;
 
   typedef QPair<DocEntry *, QString> Iter;
   QVariantList list;
@@ -124,7 +123,6 @@ QString GrantleeFormatter::formatSearchResults( const QString& words, const QLis
     list += h;
   }
 
-  Grantlee::Context ctx;
   ctx.insert( QStringLiteral("htmltitle"), i18n( "Search Results" ) );
   ctx.insert( QStringLiteral("title"), i18n( "Search Results for '%1':", words.toHtmlEscaped() ) );
   ctx.insert( QStringLiteral("results"), list );
