@@ -9,7 +9,6 @@
 #include "xapiancommon.h"
 
 #include <docbookxslt.h>
-#include <QDateTime>
 #include <QCoreApplication>
 #include <QCommandLineParser>
 #include <QDirIterator>
@@ -99,7 +98,7 @@ static void analyzeFile( const QFileInfo& cacheFile, const QString& relPath, con
     qCDebug(LOG) << "  docs to add:" << docsToAdd;
     qCDebug(LOG) << "  docs to update:" << docsToUpdate.keys();
 
-    for ( Xapian::docid id : qAsConst(docsToRemove) ) {
+    for ( Xapian::docid id : std::as_const(docsToRemove) ) {
       db.delete_document( id );
     }
 
@@ -111,7 +110,7 @@ static void analyzeFile( const QFileInfo& cacheFile, const QString& relPath, con
       db.replace_document( dtuIt.value(), doc );
     }
 
-    for ( const QString& name : qAsConst(docsToAdd) ) {
+    for ( const QString& name : std::as_const(docsToAdd) ) {
       const Xapian::Document doc = createDocument( xgen, uid, lang, std_modTime, name, cr.document( name ) );
       const Xapian::docid id = db.add_document( doc );
       handledDocuments->insert( id );
@@ -220,7 +219,7 @@ int main( int argc, char *argv[] )
     }
   }
   qCDebug(LOG) << "documentation directories:" << localDoc;
-  for ( const QString &path : qAsConst(localDoc) ) {
+  for ( const QString &path : std::as_const(localDoc) ) {
     walkFiles( path, std_lang, db, xgen, &handledDocuments );
   }
 
