@@ -9,6 +9,7 @@
 #include "grantleeformatter.h"
 #include "khc_debug.h"
 
+#include <KStandardAction>
 #include <KActionCollection>
 #include <KSharedConfig>
 #include <KLocalizedString>
@@ -260,6 +261,11 @@ void View::contextMenuEvent(QContextMenuEvent *ev)
         menu.addAction(separator);
     }
 
+    act = mActionCollection->action(KStandardAction::name(KStandardAction::Find));
+    if (act) {
+        menu.addAction(act);
+    }
+
     act = pageAction(QWebEnginePage::Copy);
     if (act->isEnabled() && hasSelection()) {
         act->setIcon(QIcon::fromTheme(QStringLiteral("edit-copy")));
